#'0' for CFI Only, '1' for On-chip (EPCS or CFI)
set ONCHIP 0

# Refer to the CPU in SOPC Builder for these numbers
set EXCEPTION_OFFSET 0x120
set RESET_OFFSET 0x00000000

# We need the size to partition the memories correctly
set SDRAM_SIZE 0x02000000
set FLASH_SIZE 0x01000000

# Used for on-chip bootloader, default 8k
set BOOT_ROM_SIZE 0x4000

# Size for the bootloader to run in SDRAM (CFI only)
set BOOTLOADER_SDRAM_SIZE  0x10000

# Here we calculate the different memory regions for the the linker
if {$ONCHIP} {

set SDRAM_REGION_START $EXCEPTION_OFFSET
set SDRAM_REGION_SIZE [expr $SDRAM_SIZE - $EXCEPTION_OFFSET]

set EXT_FLASH_REGION_START 0x20
set EXT_FLASH_REGION_SIZE [expr $FLASH_SIZE - $EXT_FLASH_REGION_START]

set BOOT_ROM_REGION_SIZE [expr $BOOT_ROM_SIZE - 0x20]

add_memory_region reset boot_rom 0x0 0x20
add_memory_region boot_rom boot_rom 0x20 $BOOT_ROM_REGION_SIZE
add_memory_region sdram sdram $SDRAM_REGION_START $SDRAM_REGION_SIZE
add_memory_region sdram_BEFORE_EXCEPTION sdram 0 $EXCEPTION_OFFSET
add_memory_region ext_flash ext_flash $EXT_FLASH_REGION_START $EXT_FLASH_REGION_SIZE

add_section_mapping .entry reset
add_section_mapping .text boot_rom
add_section_mapping .rodata boot_rom
add_section_mapping .rwdata boot_rom
add_section_mapping .stack boot_rom
add_section_mapping .heap boot_rom
add_section_mapping .bss boot_rom

} else {
#CFI Only
set EXT_FLASH_REGION_START [expr $RESET_OFFSET + 0x20]
set EXT_FLASH_REGION_SIZE [expr $FLASH_SIZE - $EXT_FLASH_REGION_START]

#We are going to use the top portion of the SDRAM to run the bootloader
set SDRAM_REGION_START [expr $SDRAM_SIZE - $BOOTLOADER_SDRAM_SIZE]
#The bottom portion of the SDRAM is where we will be loading the applicaiton
set SDRAM_BOTTOM_REGION_START $EXCEPTION_OFFSET
set SDRAM_BOTTOM_REGION_SIZE [expr $SDRAM_REGION_START - $EXCEPTION_OFFSET]

add_memory_region sdram_BEFORE_EXCEPTION sdram 0 $EXCEPTION_OFFSET
add_memory_region sdram_bottom sdram $SDRAM_BOTTOM_REGION_START $SDRAM_BOTTOM_REGION_SIZE
add_memory_region sdram sdram $SDRAM_REGION_START $BOOTLOADER_SDRAM_SIZE
add_memory_region reset ext_flash $RESET_OFFSET 0x20
add_memory_region ext_flash ext_flash $EXT_FLASH_REGION_START $EXT_FLASH_REGION_SIZE

add_section_mapping .entry reset
add_section_mapping .text sdram
add_section_mapping .rodata sdram
add_section_mapping .rwdata sdram
add_section_mapping .stack sdram
add_section_mapping .heap sdram
add_section_mapping .bss sdram
}

set_setting hal.stderr peripheral_subsystem_jtag_uart
set_setting hal.stdin peripheral_subsystem_jtag_uart
set_setting hal.stdout peripheral_subsystem_jtag_uart
set_setting hal.sys_clk_timer peripheral_subsystem_sys_clk_timer

#Build settings to minimize code size
set_setting hal.linker.allow_code_at_reset 1
set_setting hal.linker.enable_alt_load 1
if {$ONCHIP} {
set_setting hal.linker.enable_alt_load_copy_rwdata 1
set_setting hal.linker.enable_alt_load_copy_rodata 1
set_setting hal.linker.enable_alt_load_copy_exceptions 1
}
set_setting hal.linker.enable_exception_stack 0
set_setting hal.linker.exception_stack_memory_region_name sdram
set_setting hal.linker.exception_stack_size 1024
set_setting hal.make.bsp_cflags_optimization -Os
set_setting hal.max_file_descriptors 4
set_setting hal.enable_clean_exit 0
set_setting hal.enable_exit 0
set_setting hal.enable_c_plus_plus 0
set_setting hal.enable_reduced_device_drivers 1
set_setting hal.enable_small_c_library 1         

# Turn off all drivers that are not needed for the bootloader
set_driver none ext_flash
set_driver none performance_counter
set_driver none sysid
set_driver none tse_mac
set_driver none sgdma_tx
set_driver none sgdma_rx